@@ -9,6 +9,8 @@ P = t.ParamSpec("P")
 
 
 def with_session_sync(f: t.Callable[P, _RT]) -> t.Callable[P, _RT]:
+    """Decorator to handle session."""
+
     @wraps(f)
     def wrapper(*args: P.args, **kwargs: P.kwargs):
         ref = args[0]
@@ -17,8 +19,13 @@ def with_session_sync(f: t.Callable[P, _RT]) -> t.Callable[P, _RT]:
         else:
             session = None
 
+        # if session is passed as argument
+        # use it
         if session is not None:
             return f(ref, session, **kwargs)
+
+        # if session is not passed as argument
+        # and class has __session__ attribute
         elif session is None and ref.__session__ is not None:
             with ref.__session__() as session:
                 return f(ref, session, **kwargs)
@@ -29,6 +36,8 @@ def with_session_sync(f: t.Callable[P, _RT]) -> t.Callable[P, _RT]:
 
 
 def with_session_async(f: t.Callable[P, _RT]) -> t.Callable[P, _RT]:
+    """Decorator to handle session."""
+
     @wraps(f)
     async def wrapper(*args: P.args, **kwargs: P.kwargs):
         ref = args[0]
@@ -37,12 +46,15 @@ def with_session_async(f: t.Callable[P, _RT]) -> t.Callable[P, _RT]:
         else:
             session = None
 
+        # if session is passed as argument
         if session is not None:
             return await f(ref, session, **kwargs)
+
+        # if session is not passed as argument
+        # and class has __session__ attribute
         elif session is None and ref.__session__ is not None:
             async with ref.__session__() as session:
                 return await f(ref, session, **kwargs)
-
         else:
             raise ValueError("Neither function session or class session exists")
 
